@@ -1,5 +1,5 @@
 ## File Name: amh_eval_priors.R
-## File Version: 0.04
+## File Version: 0.051
 
 
 amh_eval_priors <- function( pars, prior )
@@ -7,7 +7,7 @@ amh_eval_priors <- function( pars, prior )
     NP <- length(pars)
     priorval0 <- 0
     eps <- 1E-100
-    for (pp in 1:NP){
+    for (pp in 1L:NP){
         #*** evaluate
         pars_pp <- names(pars)[pp]
         prior_arg_pp <- prior[[pp]][[2]]
