@@ -1,12 +1,11 @@
 ## File Name: amh_ic.R
-## File Version: 0.12
+## File Version: 0.131
 
 
-###################################################################
 amh_ic <- function( dev, N, pars, amh_summary, model, data, priorval )
 {
     # Information criteria
-    ic <- list( "deviance"=dev, "n"=N )
+    ic <- list( 'deviance'=dev, 'n'=N )
     ic$np <- length(pars)
     # AIC
     ic$AIC <- dev + 2*ic$np
@@ -17,7 +16,7 @@ amh_ic <- function( dev, N, pars, amh_summary, model, data, priorval )
     # corrected AIC
     ic$AICc <- ic$AIC + 2*ic$np * ( ic$np + 1 ) / ( ic$n - ic$np - 1 )
     #---- DIC
-    p1 <- amh_summary[ 1, "Mean"]
+    p1 <- amh_summary[ 1, 'Mean']
     pars_MAP <- amh_summary$Mean[-1]
     names(pars_MAP) <- names(pars)
     ll <- do.call( model, list( pars=pars_MAP, data=data ) )
@@ -28,4 +27,3 @@ amh_ic <- function( dev, N, pars, amh_summary, model, data, priorval )
     ic$logpost <- ic$loglik + ic$logprior
     return(ic)
 }
-###################################################################
