@@ -1,8 +1,8 @@
 ## File Name: confint.mlnormal.R
-## File Version: 0.08
+## File Version: 0.092
 
-###########################################
-# confidence interval
+
+#** confidence interval class mlnormal
 confint.mlnormal <- function( object, parm, level=.95,  ... )
 {
     c1 <- coef.mlnormal(object)
@@ -16,10 +16,10 @@ confint.mlnormal <- function( object, parm, level=.95,  ... )
     q2 <- 1 - ( 1 - level ) / 2
     quant <- stats::qnorm(q2)
     se <- sqrt( diag(v1) )
-    res <- data.frame( "a"=c1 - quant*se, "b"=c1 + quant*se )
-    colnames(res)[1] <- paste0( round( 100*q1,1 ), " %")
-    colnames(res)[2] <- paste0( round( 100*q2,1 ), " %")
+    res <- data.frame( 'a'=c1 - quant*se, 'b'=c1 + quant*se )
+    colnames(res)[1] <- paste0( round( 100*q1,1 ), ' %')
+    colnames(res)[2] <- paste0( round( 100*q2,1 ), ' %')
     rownames(res) <- names(c1)
     return(res)
 }
-###############################################
+
