@@ -1,5 +1,5 @@
 ## File Name: logLik_lam.R
-## File Version: 0.01
+## File Version: 0.02
 
 
 logLik_lam <- function (object, ...)
@@ -7,9 +7,9 @@ logLik_lam <- function (object, ...)
     # extract log-likelihood
     out <- - object$ic$deviance / 2
     # number of parameters
-    attr(out, "df") <- object$ic$np
+    attr(out, 'df') <- object$ic$np
     # extract number of observations
-    attr(out, "nobs") <- object$ic$n
-    class(out) <- "logLik"
+    attr(out, 'nobs') <- object$ic$n
+    class(out) <- 'logLik'
     return(out)
 }
