@@ -1,5 +1,5 @@
 ## File Name: mlnormal_update_theta_ml.R
-## File Version: 1.11
+## File Version: 1.123
 
 ###################################################
 # update theta
@@ -16,16 +16,16 @@ zz0 <- Sys.time()
     do_computation <- TRUE
 
     # list with V^(-1)%*% d V / d theta_i
-    V1_D1V_list <- as.list(1:NT)
+    V1_D1V_list <- as.list(1L:NT)
     theta0 <- theta
 
-    for (pp in 1:NT){
+    for (pp in 1L:NT){
         deri <- 0
         deri_t2 <- 0
-        H11 <- as.list(1:G)
+        H11 <- as.list(1L:G)
         #----- ! REML
         if ( ( ! REML ) | REML_shortcut  ){
-            for (gg in 1:G){
+            for (gg in 1L:G){
                 # gg <- 1
                 PV_gg <- V1_list[[gg]]
                 if ( do_compute[gg] ){
@@ -41,7 +41,7 @@ zz0 <- Sys.time()
         V1_D1V_list[[pp]] <- H11
         der[pp] <- deri + deri_t2
         }  # end if ( ! REML )
-#cat("### not REML computation ") ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
+#cat('### not REML computation ') ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
 
         #--- REML shortcut estimation | somewhat faster
         if (REML_shortcut & REML){
@@ -50,7 +50,7 @@ zz0 <- Sys.time()
             NX <- dim_X[2]
             N <- dim_X[1]
             G00 <- matrix( 0, nrow=NX, ncol=N)
-            for (gg in 1:G){
+            for (gg in 1L:G){
                 ind_gg <- id_list[[gg]]
                 G00[, ind_gg] <- crossprod( X[ ind_gg, ], V1_D1V_V1_pp_list[[gg]] )
             }
@@ -58,23 +58,22 @@ zz0 <- Sys.time()
             der_add <- 0.5 * sum( diag( solve(XVX) %*% G00 ) )
             der[pp] <- der[pp] + der_add
         }
-# cat("### not REML shortcut (alternative) ") ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
+# cat('### not REML shortcut (alternative) ') ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
 
         #----- REML
         if ( ! REML_shortcut ){
             D1_V_pp_list <- D1_V_list[[pp]]
-#  cat("* compute H_pp (V1)") ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
+#  cat('* compute H_pp (V1)') ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
             N <- dim(P)[1]
             H_pp <- matrix( 0, nrow=N, ncol=N)
-            for (gg in 1:G){
-                for (hh in 1:G){
-                    # hh <- 1
+            for (gg in 1L:G){
+                for (hh in 1L:G){
                     ind_gg <- id_list[[gg]]
                     ind_hh <- id_list[[hh]]
                     H_pp[ ind_hh, ind_gg ] <- P[ ind_hh, ind_gg ] %*% D1_V_pp_list[[gg]]
                 }
             }
-#cat("### ! REML shortcut computation ") ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
+#cat('### ! REML shortcut computation ') ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
 
             if ( ! REML_shortcut ){
                 V1_D1V_list[[pp]] <- H_pp
@@ -83,29 +82,26 @@ zz0 <- Sys.time()
 #            deri_t2 <- 0.5 * t(y) %*% H_pp %*% P %*% y
             Py <- P %*% y
             deri_t2 <- 0
-            for (gg in 1:G){
+            for (gg in 1L:G){
                 ind_gg <- id_list[[gg]]
                 Py_gg <- Py[ ind_gg, 1]
                 deri_t2 <- deri_t2 + .5* crossprod( Py_gg, D1_V_pp_list[[gg]] ) %*% Py_gg
             }
             der[pp] <- deri + deri_t2
         }   # if REML
-# cat("### REML computation ") ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
+# cat('### REML computation ') ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
 
     }  # end parameter pp
 
-# cat("-- start theta_infomat") ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
+# cat('-- start theta_infomat') ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
 
     #***** compute expected information matrix
     theta_infomat <- matrix( 0, nrow=NT, ncol=NT)
-    for (pp in 1:NT){
-        for (qq in 1:pp){
-            # pp <- 1
-            # qq <- 1
+    for (pp in 1L:NT){
+        for (qq in 1L:pp){
             #-------- ML -----------------
             if ( REML_shortcut ){
-                for (gg in 1:G){
-                    # gg <- 1
+                for (gg in 1L:G){
                     if ( do_compute[gg] ){
                         #*** remove this line @ARb 2016-07-15
                         # a2 <- V1_D1V_list[[pp]][[gg]] * V1_D1V_list[[qq]][[gg]]
@@ -133,38 +129,37 @@ zz0 <- Sys.time()
     if ( prior_args$use_prior ){
         res <- mlnormal_eval_priors_derivative2( pars=theta,
                     prior=prior_args$prior, h=prior_args$numdiff.parm )
-        # der <- der + res$der
         der <- der - res$der
         theta_infomat1 <- theta_infomat1 - res$infomat
     }
     #--- derivative in case of penalties
     if ( prior_args$use_penalty ){
         res_newton <- mlnormal_eval_penalty_update_theta( theta=theta,
-                    prior_args=prior_args, iter=iter, der=der,
-                    theta_infomat1=theta_infomat1,
-                    control_theta=control_theta)
+                            prior_args=prior_args, iter=iter, der=der,
+                            theta_infomat1=theta_infomat1,
+                            control_theta=control_theta)
         theta <- res_newton$theta
     }
 
     #--- Newton step
     if ( prior_args$use_prior | prior_args$use_GLS ){
         res_newton <- mlnormal_update_theta_newton_step( theta=theta, der=der,
-                        theta_infomat=theta_infomat1, control_theta=control_theta )
+                            theta_infomat=theta_infomat1, control_theta=control_theta )
         theta <- res_newton$theta
     }
 
     # bounds
     theta <- sirt::bounds_parameters( pars=theta, lower=control_theta$theta_lower,
-                    upper=control_theta$theta_upper )
+                        upper=control_theta$theta_upper )
     theta_change <- mlnormal_parameter_change( pars=theta, pars0=theta0 )
 
     # convert to vector
     theta <- mlnormal_as_vector_names(pars=theta, parnames=names(theta0) )
 
     #--- output
-    res <- list( "der"=der, "yresid"=yresid, "V1_D1V_list"=V1_D1V_list,
-            "theta_infomat"=res_newton$theta_infomat, "Hinv"=res_newton$Hinv,
-            "theta"=theta, "theta_change"=theta_change,
-            theta_increment=theta - theta0 )
+    res <- list( der=der, yresid=yresid, V1_D1V_list=V1_D1V_list,
+            theta_infomat=res_newton$theta_infomat, Hinv=res_newton$Hinv,
+            theta=theta, theta_change=theta_change,
+            theta_increment=theta-theta0 )
     return(res)
 }
