@@ -1,11 +1,11 @@
 ## File Name: mlnormal_verbose_f1.R
-## File Version: 0.05
+## File Version: 0.061
 
 mlnormal_verbose_f1 <- function(verbose, disp, iter)
 {
     if ( verbose ){
         cat(disp)
-        cat("Iteration", iter, "   ", paste( Sys.time() ), "\n" )
+        cat('Iteration', iter, '   ', paste( Sys.time() ), '\n' )
     }
 }
 
